import fetch from 'cross-fetch';
const isErrorResponse = (data) => {
    const isObject = typeof data === 'object' && data !== null;
    return isObject && 'code' in data && 'message' in data;
};
function replaceParam(str, key, value) {
    return str.replace(new RegExp(`\\{${key}\\}`, 'g'), value);
}
export function insertParams(template, params) {
    return params
        ? Object.keys(params).reduce((result, key) => {
            return replaceParam(result, key, String(params[key]));
        }, template)
        : template;
}
export function stringifyQuery(query) {
    if (!query) {
        return '';
    }
    const searchParams = new URLSearchParams();
    Object.keys(query).forEach((key) => {
        if (query[key] != null) {
            searchParams.append(key, String(query[key]));
        }
    });
    const searchString = searchParams.toString();
    return searchString ? `?${searchString}` : '';
}
export async function fetchData(url, body) {
    let options;
    if (body != null) {
        options = {
            method: 'POST',
            body: typeof body === 'string' ? body : JSON.stringify(body),
            headers: { 'Content-Type': 'application/json' }
        };
    }
    const resp = await fetch(url, options);
    let json;
    try {
        json = await resp.json();
    }
    catch {
        if (resp.headers && resp.headers.get('content-length') !== '0') {
            throw new Error(`Invalid response content: ${resp.statusText}`);
        }
    }
    if (!resp.ok) {
        const errTxt = isErrorResponse(json) ? `${json.code}: ${json.message}` : resp.statusText;
        throw new Error(errTxt);
    }
    return json;
}
//# sourceMappingURL=utils.js.map